@@ -45,14 +45,14 @@ public:
     kpToolTextEnterCommand (const QString &name,
         int row, int col, Action action,
         kpCommandEnvironment *environ);
-    virtual ~kpToolTextEnterCommand ();
+    ~kpToolTextEnterCommand () override;
 
     void addEnter ();
 
-    kpCommandSize::SizeType size () const Q_DECL_OVERRIDE;
+    kpCommandSize::SizeType size () const override;
 
-    void execute () Q_DECL_OVERRIDE;
-    void unexecute () Q_DECL_OVERRIDE;
+    void execute () override;
+    void unexecute () override;
 
 protected:
     int m_row, m_col;
