@@ -31,8 +31,6 @@
 #include "kpMainWindowPrivate.h"
 
 #include <QAction>
-#include <QDataStream>
-#include <QDesktopWidget>
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QFileDialog>
@@ -41,7 +39,6 @@
 #include <QSize>
 #include <QPrinter>
 #include <QPrintDialog>
-#include <QScreen>
 #include <QApplication>
 #include <QTimer>
 #include <QLabel>
@@ -51,6 +48,7 @@
 #include <QImageWriter>
 #include <QMimeDatabase>
 #include <QPrintPreviewDialog>
+#include <QScreen>
 
 #include <KActionCollection>
 #include <KEMailClientLauncherJob>
@@ -78,6 +76,7 @@
 
 #if HAVE_KSANE
 #include "../scan/sanedialog.h"
+#include <kwidgetsaddons_version.h>
 #endif // HAVE_KSANE
 
 // private
@@ -543,7 +542,7 @@ void kpMainWindow::slotScan ()
         // No scanning support (kdegraphics/libkscan) installed?
         if (!d->scanDialog)
         {
-            KMessageBox::sorry (this,
+            KMessageBox::error (this,
                                 i18n("Failed to open scanning dialog."),
                                 i18nc("@title:window", "Scanning Failed"));
             return;
@@ -698,7 +697,7 @@ void kpMainWindow::slotScreenshot()
 void kpMainWindow::slotMakeScreenshot()
 {
   QCoreApplication::processEvents();
-  QPixmap pixmap = QGuiApplication::primaryScreen()->grabWindow(QApplication::desktop()->winId());
+  QPixmap pixmap = QGuiApplication::primaryScreen()->grabWindow(0 /* entire screen*/);
 
   auto *doc = new kpDocument(pixmap.width(), pixmap.height(), documentEnvironment());
   doc->setImage(pixmap.toImage());
@@ -1406,13 +1405,21 @@ void kpMainWindow::slotMail ()
         !(d->document->isFromExistingURL () && d->document->urlExists (d->document->url ())) ||
         d->document->isModified ()/*needs to be saved*/)
     {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        int result = KMessageBox::questionTwoActions(this,
+#else
         int result = KMessageBox::questionYesNo (this,
+#endif
                         i18n ("You must save this image before sending it.\n"
                               "Do you want to save it?"),
                         QString(),
                         KStandardGuiItem::save (), KStandardGuiItem::cancel ());
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (result == KMessageBox::ButtonCode::PrimaryAction)
+#else
         if (result == KMessageBox::Yes)
+#endif
         {
             if (!save ())
             {
@@ -1444,7 +1451,11 @@ bool kpMainWindow::queryCloseDocument ()
         return true;  // ok to close current doc
     }
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    int result = KMessageBox::warningTwoActionsCancel(this,
+#else
     int result = KMessageBox::warningYesNoCancel (this,
+#endif
                      i18n ("The document \"%1\" has been modified.\n"
                            "Do you want to save it?",
                            d->document->prettyFilename ()),
@@ -1453,9 +1464,17 @@ bool kpMainWindow::queryCloseDocument ()
 
     switch (result)
     {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::ButtonCode::PrimaryAction:
+#else
     case KMessageBox::Yes:
+#endif
         return slotSave ();  // close only if save succeeds
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::ButtonCode::SecondaryAction:
+#else
     case KMessageBox::No:
+#endif
         return true;  // close without saving
     default:
         return false;  // don't close current doc
