@@ -28,7 +28,6 @@
 #include "mainWindow/kpMainWindow.h"
 #include "kpMainWindowPrivate.h"
 
-#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <KSharedConfig>
 #include <KConfigGroup>
@@ -56,21 +55,13 @@ void kpMainWindow::setupTextToolBarActions ()
     d->actionTextFontFamily = ac->add<KFontAction> (QStringLiteral("text_font_family"));
     d->actionTextFontFamily->setText (i18n ("Font Family"));
     connect (d->actionTextFontFamily,
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
              &KSelectAction::textTriggered,
-#else
-             static_cast<void (KFontAction::*)(const QString&)>(&KFontAction::triggered),
-#endif
              this, &kpMainWindow::slotTextFontFamilyChanged);
 
     d->actionTextFontSize = ac->add<KFontSizeAction> (QStringLiteral("text_font_size"));
     d->actionTextFontSize->setText (i18n ("Font Size"));
     connect (d->actionTextFontSize,
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
              &KSelectAction::indexTriggered,
-#else
-             static_cast<void (KFontSizeAction::*)(int)>(&KFontSizeAction::triggered),
-#endif
              this, &kpMainWindow::slotTextFontSizeChanged);
 
     d->actionTextBold = ac->add<KToggleAction> (QStringLiteral("text_bold"));
